---
name: Bug report
about: Create a report to help us improve
title: "[BUG] Please add your bug title here"
labels: bug
assignees: ''

---

<!-- Please provide as much detail as possible to help us understand and reproduce the issue. This will enable us to address it more effectively. -->

## Describe the bug
<!-- A clear and concise description of what the bug is. -->

## Steps to Reproduce
<!-- Steps to reproduce the behavior. For example:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error
-->

## Expected behavior
<!-- A clear and concise description of what you expected to happen. -->

## Screenshots
<!-- If applicable, add screenshots to help explain your problem. -->

## Environment
<!-- Please provide information about your environment. For example:
- OS: [e.g. iOS]
- Browser [e.g. chrome, safari]
- Version [e.g. 22]
-->

## Additional context
<!-- Add any other context about the problem here. -->

## Applicable Stack Trace
<!-- If applicable, add the full stack trace or the clearly applicable sections of the stack trace here. -->
